"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.securityLoader = exports.httpClientHandler = void 0;
/*!
 * Copyright (c) 2021 Interop Alliance and Dmitri Zagidulin. All rights reserved.
 */
const didKey = __importStar(require("@digitalcredentials/did-method-key"));
const didWeb = __importStar(require("@interop/did-web-resolver"));
const vc2Context = __importStar(require("@digitalcredentials/credentials-v2-context"));
const vcBitstringStatusListContext = __importStar(require("@digitalbazaar/vc-bitstring-status-list-context"));
const credentials_context_1 = __importDefault(require("credentials-context"));
const vc_status_list_context_1 = __importDefault(require("@digitalbazaar/vc-status-list-context"));
const data_integrity_context_1 = __importDefault(require("@digitalbazaar/data-integrity-context"));
const ed25519_verification_key_2020_1 = require("@digitalcredentials/ed25519-verification-key-2020");
const x25519_key_agreement_key_2020_1 = require("@digitalcredentials/x25519-key-agreement-key-2020");
const did_io_1 = require("@digitalcredentials/did-io");
const dcc_context_1 = __importDefault(require("@digitalcredentials/dcc-context"));
const did_context_1 = __importDefault(require("did-context"));
const ed25519_signature_2020_context_1 = __importDefault(require("ed25519-signature-2020-context"));
const x25519_key_agreement_2020_context_1 = __importDefault(require("x25519-key-agreement-2020-context"));
const jsonld_document_loader_1 = require("jsonld-document-loader");
const crypto_ld_1 = require("@digitalcredentials/crypto-ld");
const open_badges_context_1 = __importDefault(require("@digitalcredentials/open-badges-context"));
const http_client_1 = require("@digitalcredentials/http-client");
const parseResponse_1 = require("./parseResponse");
const cryptoLd = new crypto_ld_1.CryptoLD();
cryptoLd.use(ed25519_verification_key_2020_1.Ed25519VerificationKey2020);
cryptoLd.use(x25519_key_agreement_key_2020_1.X25519KeyAgreementKey2020);
const didWebDriver = didWeb.driver({ cryptoLd });
const didKeyDriver = didKey.driver();
const resolver = new did_io_1.CachedResolver();
resolver.use(didKeyDriver);
resolver.use(didWebDriver);
exports.httpClientHandler = {
    /**
     * @param {object} options - Options hashmap.
     * @param {string} options.url - Document URL.
     * @returns {Promise<{contextUrl: null, document, documentUrl}>} - Resolves
     *   with documentLoader document.
     */
    async get(params) {
        if (!params.url.startsWith('http')) {
            throw new Error('NotFoundError');
        }
        let result;
        try {
            const headers = {
                'Cache-Control': 'no-cache',
                'Pragma': 'no-cache'
            };
            result = await http_client_1.httpClient.get(params.url, { headers, parseBody: false });
        }
        catch (e) {
            throw new Error(`NotFoundError loading "${params.url}": ${e.message}`);
        }
        return (0, parseResponse_1.parseResponseBody)(result);
    }
};
function securityLoader({ fetchRemoteContexts = false, useOBv3BetaContext = false } = {}) {
    const loader = new jsonld_document_loader_1.JsonLdDocumentLoader();
    // Ed25519 Signature 2020 Context
    loader.addStatic(ed25519_signature_2020_context_1.default.constants.CONTEXT_URL, ed25519_signature_2020_context_1.default.contexts.get(ed25519_signature_2020_context_1.default.constants.CONTEXT_URL));
    // X25519 Key Agreement 2020 Context
    loader.addStatic(x25519_key_agreement_2020_context_1.default.constants.CONTEXT_URL, x25519_key_agreement_2020_context_1.default.contexts.get(x25519_key_agreement_2020_context_1.default.constants.CONTEXT_URL));
    // DID Context
    loader.addStatic(did_context_1.default.constants.DID_CONTEXT_URL, did_context_1.default.contexts.get(did_context_1.default.constants.DID_CONTEXT_URL));
    // Verifiable Credentials Data Model 1.0 Context
    loader.addStatic(credentials_context_1.default.CONTEXT_URL, credentials_context_1.default.CONTEXT);
    // Verifiable Credentials Data Model 2.0 Context - BETA / non-final
    loader.addStatic(vc2Context.CONTEXT_URL, vc2Context.CONTEXT);
    // Data Integrity Context
    for (const [url, context] of data_integrity_context_1.default.contexts) {
        loader.addStatic(url, context);
    }
    // DCC Context
    loader.addStatic(dcc_context_1.default.CONTEXT_URL_V1, dcc_context_1.default.CONTEXT_V1);
    // Bitstring Status List Context
    loader.addStatic(vcBitstringStatusListContext.CONTEXT_URL, vcBitstringStatusListContext.CONTEXT);
    // Status List 2021 Context (DEPRECATED)
    loader.addStatic(vc_status_list_context_1.default.CONTEXT_URL_V1, vc_status_list_context_1.default.CONTEXT_V1);
    // Open Badges v3 Contexts, includes OBv3 Beta, 3.0, 3.0.1, 3.0.2, etc.
    for (const [url, context] of open_badges_context_1.default.contexts) {
        loader.addStatic(url, context);
    }
    if (useOBv3BetaContext) {
        // Workaround to validate legacy OBv3 BETA context VCs
        loader.addStatic(open_badges_context_1.default.CONTEXT_URL_V3_0_0, open_badges_context_1.default.contexts.get(open_badges_context_1.default.CONTEXT_URL_V3_BETA));
    }
    loader.setDidResolver(resolver);
    // Enable loading of arbitrary contexts from web
    if (fetchRemoteContexts) {
        loader.setProtocolHandler({ protocol: 'http', handler: exports.httpClientHandler });
        loader.setProtocolHandler({ protocol: 'https', handler: exports.httpClientHandler });
    }
    return loader;
}
exports.securityLoader = securityLoader;
//# sourceMappingURL=documentLoader.js.map